Class: Google::Cloud::Maintenance::Api::V1beta::ListResourceMaintenancesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb

Overview

The response structure for the ListResourceMaintenances method.

Instance Attribute Summary collapse

Instance Attribute Details

#next_page_token::String

Returns If present, the next page token can be provided to a subsequent ListResourceMaintenances call to list the next page. If empty, there are no more pages.

Returns:

  • (::String)

    If present, the next page token can be provided to a subsequent ListResourceMaintenances call to list the next page. If empty, there are no more pages.



385
386
387
388
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 385

class ListResourceMaintenancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_maintenances::Array<::Google::Cloud::Maintenance::Api::V1beta::ResourceMaintenance>

Returns The resulting resource maintenances.

Returns:



385
386
387
388
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 385

class ListResourceMaintenancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Locations that could not be reached.



385
386
387
388
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 385

class ListResourceMaintenancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end