Class: Google::Cloud::Maintenance::Api::V1beta::MaintenanceControl

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb

Overview

The control of the maintenance.

Defined Under Namespace

Modules: Control

Instance Attribute Summary collapse

Instance Attribute Details

#control::Google::Cloud::Maintenance::Api::V1beta::MaintenanceControl::Control

Returns The control of the resource maintenance.

Returns:



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 331

class MaintenanceControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Sets the type of control supported. comment (as in logs).
  module Control
    # Unspecified control.
    CONTROL_UNSPECIFIED = 0

    # Apply control.
    APPLY = 1

    # Manage policy control.
    MANAGE_POLICY = 2

    # Reschedule control.
    RESCHEDULE = 3
  end
end

#documentation::String

Returns Link to Service Producer documentation about maintenance control. Provided only when isCustom is true.

Returns:

  • (::String)

    Link to Service Producer documentation about maintenance control. Provided only when isCustom is true.



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 331

class MaintenanceControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Sets the type of control supported. comment (as in logs).
  module Control
    # Unspecified control.
    CONTROL_UNSPECIFIED = 0

    # Apply control.
    APPLY = 1

    # Manage policy control.
    MANAGE_POLICY = 2

    # Reschedule control.
    RESCHEDULE = 3
  end
end

#is_custom::Boolean

Returns Indicates whether the control is available only in Service Producer API (not through Unified Maintenance).

Returns:

  • (::Boolean)

    Indicates whether the control is available only in Service Producer API (not through Unified Maintenance).



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 331

class MaintenanceControl
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods

  # Sets the type of control supported. comment (as in logs).
  module Control
    # Unspecified control.
    CONTROL_UNSPECIFIED = 0

    # Apply control.
    APPLY = 1

    # Manage policy control.
    MANAGE_POLICY = 2

    # Reschedule control.
    RESCHEDULE = 3
  end
end