Class: Google::Cloud::Maintenance::Api::V1beta::ResourceMaintenance::Maintenance

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb

Overview

Maintenance is the maintenance details of a resource's maintenance.

Instance Attribute Summary collapse

Instance Attribute Details

#category::Google::Cloud::Maintenance::Api::V1beta::MaintenanceCategory (readonly)

Returns Output only. The category of the maintenance.

Returns:



274
275
276
277
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 274

class Maintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#description::String (readonly)

Returns Output only. The description of the maintenance.

Returns:

  • (::String)

    Output only. The description of the maintenance.



274
275
276
277
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 274

class Maintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#maintenance_name::String

Returns Maintenance is the name of the corresponding maintenance resource following the standard naming scheme: "{maintenance-id}".

Returns:

  • (::String)

    Maintenance is the name of the corresponding maintenance resource following the standard naming scheme: "{maintenance-id}"



274
275
276
277
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 274

class Maintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#title::String (readonly)

Returns Output only. The title of the maintenance.

Returns:

  • (::String)

    Output only. The title of the maintenance.



274
275
276
277
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 274

class Maintenance
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end