Class: Google::Cloud::Maintenance::Api::V1beta::ResourceMaintenance::Resource

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb

Overview

Resource contains information about the resource affected by maintenance.

Instance Attribute Summary collapse

Instance Attribute Details

#location::String (readonly)

Returns Output only. The location of the resource. Format: us-central1.

Returns:

  • (::String)

    Output only. The location of the resource. Format: us-central1



255
256
257
258
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 255

class Resource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#resource_name::String (readonly)

Returns Output only. Name is the reference to the consumer resource affected by the maintenance. Available values can be found here: https://cloud.google.com/asset-inventory/docs/asset-names.

Returns:



255
256
257
258
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 255

class Resource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#type::String (readonly)

Returns Output only. The type of the resource. Available values can be found here: https://cloud.google.com/asset-inventory/docs/asset-types#supported_resource_types Please note that not all the resource types will have their maintenances reported.

Returns:



255
256
257
258
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 255

class Resource
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end