Class: Google::Cloud::Maintenance::Api::V1beta::SummarizeMaintenancesRequest

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb

Overview

Request message for SummarizeMaintenances custom method.

Instance Attribute Summary collapse

Instance Attribute Details

#filter::String

Returns Filter the list as specified in https://google.aip.dev/160. Supported fields include:

  • state
  • resource.location
  • resource.resourceName
  • resource.type
  • maintenance.maintenanceName
  • maintenanceStartTime
  • maintenanceCompleteTime Examples:
  • state="SCHEDULED"
  • resource.location="us-central1-c"
  • resource.resourceName=~"*/instance-20241212-211259"
  • maintenanceStartTime>"2000-10-11T20:44:51Z"
  • state="SCHEDULED" OR resource.type="compute.googleapis.com/Instance"
  • maintenance.maitenanceName="eb3b709c-9ca1-5472-9fb6-800a3849eda1" AND maintenanceCompleteTime>"2000-10-11T20:44:51Z".

Returns:

  • (::String)

    Filter the list as specified in https://google.aip.dev/160. Supported fields include:

    • state
    • resource.location
    • resource.resourceName
    • resource.type
    • maintenance.maintenanceName
    • maintenanceStartTime
    • maintenanceCompleteTime Examples:
    • state="SCHEDULED"
    • resource.location="us-central1-c"
    • resource.resourceName=~"*/instance-20241212-211259"
    • maintenanceStartTime>"2000-10-11T20:44:51Z"
    • state="SCHEDULED" OR resource.type="compute.googleapis.com/Instance"
    • maintenance.maitenanceName="eb3b709c-9ca1-5472-9fb6-800a3849eda1" AND maintenanceCompleteTime>"2000-10-11T20:44:51Z"


60
61
62
63
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 60

class SummarizeMaintenancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#order_by::String

Returns Order results as specified in https://google.aip.dev/132.

Returns:



60
61
62
63
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 60

class SummarizeMaintenancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_size::Integer

Returns The maximum number of resource maintenances to send per page. The default page size is 20 and the maximum is 1000.

Returns:

  • (::Integer)

    The maximum number of resource maintenances to send per page. The default page size is 20 and the maximum is 1000.



60
61
62
63
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 60

class SummarizeMaintenancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#page_token::String

Returns The page token: If the next_page_token from a previous response is provided, this request will send the subsequent page.

Returns:

  • (::String)

    The page token: If the next_page_token from a previous response is provided, this request will send the subsequent page.



60
61
62
63
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 60

class SummarizeMaintenancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#parent::String

Returns Required. The parent of the resource maintenance. eg. projects/123/locations/*.

Returns:

  • (::String)

    Required. The parent of the resource maintenance. eg. projects/123/locations/*



60
61
62
63
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 60

class SummarizeMaintenancesRequest
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end