Class: Google::Cloud::Maintenance::Api::V1beta::SummarizeMaintenancesResponse

Inherits:
Object
  • Object
show all
Extended by:
Protobuf::MessageExts::ClassMethods
Includes:
Protobuf::MessageExts
Defined in:
proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb

Overview

Request message for SummarizeMaintenances custom method.

Instance Attribute Summary collapse

Instance Attribute Details

#maintenances::Array<::Google::Cloud::Maintenance::Api::V1beta::MaintenanceSummary>

Returns The resulting summaries.

Returns:



77
78
79
80
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 77

class SummarizeMaintenancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#next_page_token::String

Returns If present, the next page token can be provided to a subsequent SummarizeMaintenances call to list the next page. If empty, there are no more pages.

Returns:

  • (::String)

    If present, the next page token can be provided to a subsequent SummarizeMaintenances call to list the next page. If empty, there are no more pages.



77
78
79
80
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 77

class SummarizeMaintenancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end

#unreachable::Array<::String>

Returns Unordered list. Locations that could not be reached.

Returns:

  • (::Array<::String>)

    Unordered list. Locations that could not be reached.



77
78
79
80
# File 'proto_docs/google/cloud/maintenance/api/v1beta/maintenance_service.rb', line 77

class SummarizeMaintenancesResponse
  include ::Google::Protobuf::MessageExts
  extend ::Google::Protobuf::MessageExts::ClassMethods
end